(use-translation _ "alterator-i18n")

(include-as-is "/dialog/functions")

(on-apply (apply-lang))

(define (get-locales)
  (woo-read-names
    "/i18n/available"
    (woo-list
      "/i18n/available")))

(define (get-current-locale)
  (woo-first-command
    (woo-read "/i18n/current")))

(define (on-load-error reason) '())

(define *locales* (woo-catch get-locales on-load-error))
(define *current-locale* (woo-catch get-current-locale on-load-error))

(define *current-locale-number* (string-list-index (woo-get-option *current-locale*
								   'title)
					   *locales*))

(define (get-by-title title option)
  (woo-get-option
    (woo-first-command (woo-read (string-append "/i18n/available/"
						title)))
    option))

(define (get-stdname title)
  (get-by-title title 'stdname))

(define (get-charsets title)
  (string-splitting (get-by-title title 'charmaps) #\,))

(define (apply-lang)
  (woo-catch
    (lambda ()
      (woo-write "/i18n/current"
		 'lang
		 (string-append (get-stdname (locales text))
				"."
				(charset text)))
      (run-dialog `(/information
		    message
		    ,(_ "Don't forget to re-login to system to apply changes"))))
    (lambda(reason)
      (run-dialog `("/error" reason ,reason)))))


(define *current-charset-list* (woo-catch
			     (lambda ()
				 (get-charsets (woo-get-option *current-locale* 'title)))
			     on-load-error))

(define *current-charset-number* (or
				   (string-list-index (woo-get-option *current-locale*
								      'charmap)
						      *current-charset-list*)
				   (string-list-index "UTF-8"
						      *current-charset-list*)
				   0))

(define (update-charset)
  (woo-catch
    (lambda()
      (let ((chset (get-charsets (locales text))))
	(charset (items chset))
	(if (and *current-locale-number*
	         (= (locales current) *current-locale-number*))
	  (charset current *current-charset-number*)
	  (charset current (or (string-list-index "UTF-8" chset)
			       0)))))
    (lambda(reason) #t)))

(id 'pages
    (tabbox
      (relative-width 100 page)
      (relative-height 80 page)
      (tab 'basic-settings (_ "Basic settings")
	   sizepolicy 'fixed
	   spacing 1
	   margin 2
	   (label (_ "Choose your locale:"))
	   (id 'locales
	       (listbox
		 (relative-width 50 pages)
		 (relative-height 80 pages)
		 (items *locales*)
		 (if *current-locale-number* (current *current-locale-number*))
		 (on-select (update-charset)))))

      (tab 'advanced-settings (_ "Advanced")
	   sizepolicy 'fixed
	   (hbox
	     spacing 1
	     margin 2
	     sizepolicy 'fixed
	     (label (_ "Charset:"))
	     (id 'charset
		 (combobox
		   (items *current-charset-list*)
		   current *current-charset-number*))))
      (current basic-settings)))

